#
# spec file for package balsa
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           balsa
Version:        2.6.5
Release:        1.2
Summary:        The GNOME Mail Program
License:        GPL-2.0-or-later
URL:            https://gitlab.gnome.org/GNOME/balsa
Source0:        %{name}-%{version}.tar.zst

BuildRequires:  fdupes
BuildRequires:  meson
BuildRequires:  pkgconfig(enchant-2)
BuildRequires:  pkgconfig(fribidi)
BuildRequires:  pkgconfig(gio-2.0)
BuildRequires:  pkgconfig(glib-2.0)
BuildRequires:  pkgconfig(gmime-3.0)
BuildRequires:  pkgconfig(gnutls)
BuildRequires:  pkgconfig(gpgme)
BuildRequires:  pkgconfig(gthread-2.0)
BuildRequires:  pkgconfig(gtk+-3.0)
BuildRequires:  pkgconfig(libical)
BuildRequires:  pkgconfig(libsecret-1)
BuildRequires:  pkgconfig(webkit2gtk-4.1)

%description
An e-mail client for GNOME. It supports
* the local mailbox formats mbox, maildir and mh
* MIME support, nested mailboxes
* POP3 and IMAP mail access
* printing, spell checking
* address book with GnomeCard
* GPG/OpenPGP mail signing and encryption

%lang_package

%prep
%autosetup -p1

%build
%meson \
	%{nil}
%meson_build

%install
%meson_install

%find_lang %{name} %{?no_lang_C}
%fdupes %{buildroot}%{_datadir}

%files
%license COPYING
%doc README.md ChangeLog NEWS TODO AUTHORS HACKING
%doc docs/mh-mail-HOWTO docs/vconvert.awk docs/pine2vcard
%{_bindir}/*
%{_datadir}/applications/*.desktop
%{_datadir}/balsa/
%dir %{_datadir}/metainfo
%{_datadir}/metainfo/balsa.appdata.xml
%{_datadir}/pixmaps/*.png
%{_datadir}/sounds/balsa
%{_mandir}/man1/balsa.1%{?ext_man}
%dir %{_sysconfdir}/sound
%dir %{_sysconfdir}/sound/events
%config %{_sysconfdir}/sound/events/*.soundlist
%dir %{_libdir}/%{name}
%{_libdir}/%{name}/libhtmlfilter.so

%files lang -f %{name}.lang

%changelog
* Thu Apr 17 2025 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 2.6.5:
  + fix connection issues with broken IMAP servers
  + add limited support for CardDAV address books
  + always store user credentials in the Secret Service if possible
  + improve dealing with user credentials iff the Secret Service is
    unusable
  + improve saving attachments
  + improved setup wizard with server probing
  + add support for Web Key Directory (WKD) GnuPG keys
  + improve crypto user interface
  + add optional DKIM and DMARC checks
  + prefer TLS connections over STARTTLS
  + Webkit 4.1 support
  + use XDG-compliant user data folder layout
  + remove deprecated stuff (SQLite2, Rubrica, ige-mac-integration)
  + lots of bug fixes
  + documentation updates (yet incomplete)
  + port to meson
- Drop balsa-webkitgtk-bump.patch: Fixed upstream.
- Switch to git checkout via source service.
- Add meson BuildRequries and macros following upstreams port.
- Align Buildrequires with what meson setup checks for, follow
  upstream defaults.
* Sun Mar 12 2023 Bjørn Lie <bjorn.lie@gmail.com>
- Add balsa-webkitgtk-bump.patch: Port to build against
  webkit2gtk-4.1. Following this replace pkgconfig(webkit2gtk-4.0)
  with pkgconfig(webkit2gtk-4.1) BuildRequires, and add libtool
  BuildRequires and bootstrap the build since the patch touches the
  buildsystem.
* Fri Oct 21 2022 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 2.6.4:
  + Fix display/printout with nondefault HTML preferences.
  + HTML context meny improments, integration with Webkit HTML
    privacy filter.
  + Header edition in GNOME editor fixed.
  + Some MDN, iCalendar issues fixed.
  + More informative error messages.
  + Notification improvements.
  + Show UI for opening download location after download.
  + Minor memory leaks plugged.
  + Code refactoring and cleanup.
  + Library and build system deprecation cleanups.
  + Updated translations.
- Pass disable static to configure and remove la files in install.
- Replace gpgme-devel with pkgconfig(gpgme) BuildRequires following
  upstreams changes.
* Wed Dec 29 2021 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 2.6.3:
  + Improve Autocrypt-related error messages.
  + Improvements to communication with GnuPG key servers.
  + Create standard-compatible HTML messages.
  + Implement sender-dependent HTML message preferences.
  + Reuse HTTP connections when rendering HTML messages.
  + Do not send empty Reply-To, Cc, etc headers.
  + More robust IMAP parser and response handling.
  + Code cleanups, platform-dependent build fixes.
* Mon Dec 28 2020 Paolo Stivanin <info@paolostivanin.com>
- Update to version 2.6.2:
  * Webkit widgets are now sandboxed.
  * Improved desktop notifications.
  * iTIP calendar reply are improved.
  * Handling of multiple crypto keys for the same recipient.
  * build cleanups and improvements, e.g. application logging.
  * code cleanups and simplifications as enabled by moving to more modern
    libraries.
  * bug fixes: draft with message/external-body attachments;
    do not crash on importing half-broken keys
* Wed Jul 29 2020 Matthias Eliasson <elimat@opensuse.org>
- Update to version 2.6.1:
  + fix server identity verification.
- Run spec-cleaner
  + Remove package groups
* Sun Apr 12 2020 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 2.6.0:
  + This release switches to gmime3 library for MIME processing.
- Replace pkgconfig(gmime-2.6) with pkgconfig(gmime-3.0)
  BuildRequires following upstreams port.
* Sun Apr 12 2020 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 2.5.10:
  + Set message threading correctly on new mailboxes.
  + Display S/MIME and TLS certificate chains.
  + Improve handling of multipart/related message parts.
  + Display text/calendar parts using ical library.
  + Multiple bug fixes and code cleanups; remove obsolete command
    line options.
- Changes from version 2.5.9:
  + Fix HTML message layout issues.
- Add pkgconfig(libical) and pkgconfig(libsecret-1) BuildRequires:
  New dependencies.
* Wed Oct 16 2019 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 2.5.8:
  + HTML email improvements; vcal attachment handling.
- Changes from version 2.5.7:
  + encryption, HTML email improvements; bug fixes.
- Drop conditional post(un) handling for obsolete versions of
  openSUSE.
- Drop balsa-2.5.6-fix-build-breaker-typo.patch: Fixed upstream.
- Drop update-desktop-files BuildRequires and macros as well as
  balsa-lang Recommends, no longer needed.
- Add pkgconfig(fribidi) BuildRequires: New dependency.
* Sun Jul  8 2018 bjorn.lie@gmail.com
- Drop pkgconfig(libnm-glib) BuildRequires: Balsa switched from
  libnm-glib to GNetworkMonitor in version 2.5.2.
- Drop pkgconfig(libsecret-1) BuildRequires: Not used, as we are
  not passing --with-libsecret to configure (upstream default is
  not using it).
- Stop passing --enable-smime, --with-gtkspell and --with-ssl to
  configure, no longer recognized.
- Replace pkgconfig(gtkspell3-3.0) with pkgconfig(gspell-1)
  BuildRequires and pass --with-spell-checker=gspell to configure.
  This also allows for dropping conditionals for
  pkgconfig(enchant-2) and pkgconfig(enchant) BuildRequires.
- Replace openssl-devel with pkgconfig(openssl) BuildRequires,
  align with what configure checks for.
* Thu Jun 28 2018 antoine.belvire@opensuse.org
- Update to version 2.5.6:
  + Fix scroll on click issue.
  + Display time stamps of date-only RFC 5545 iCalendar events.
  + Disable reply-to-group when the message is not from an
    RFC-2369-compliant mail list.
  + Mitigate EFail vulnerability for Webkit2.
- Fix a typo that breaks build in released version:
  + Add balsa-2.5.6-fix-build-breaker-typo.patch (picked from
    upstream).
* Sat Apr  7 2018 bjorn.lie@gmail.com
- Update to version 2.5.5:
  + Crypto performance improvements.
  + Updates to match glib-2.56 API changes.
  + Fix use-after-free bugs.
  + Improve replying to HTML-only messages.
  + Low level networking re-done.
  + Multiple bugfixes.
- Drop balsa-build-ssl-1.1.patch: Fixed upstream.
- Run spec-cleaner, modernize spec.
- Add pkgconfig(gnutls) and python3-html2text BuildRequires: New
  dependencies.
- Drop conditional compface BuildRequires.
- Add conditional for pkgconfig(enchant) and new
  pkgconfig(enchant-2) BuildRequires.
* Thu Jan 25 2018 jengelh@inai.de
- Replace untrue description.
* Thu Jan 18 2018 zaitor@opensuse.org
- Clean up spec:
  + Drop old and unused pre_checkin.sh for TOUCHSCREEN_OPTIMIZATION
    and all conditionals related to it (base_name et al.).
  + Fixup compface BuildRequires to only be for non-openSUSE.
  + Drop translation-update-upstream BuildRequires and macro.
* Sun Dec  3 2017 zaitor@opensuse.org
- Add balsa-build-ssl-1.1.patch: Fix build with new openssl 1.1.0.
* Sun Aug 20 2017 zaitor@opensuse.org
- Drop obsolete pkgconfig(unique-1.0) BuildRequires: No longer
  needed, nor used.
* Wed Mar  8 2017 zaitor@opensuse.org
- Update to version 2.5.3:
  + More bugfixes and ports.
* Sat Oct  8 2016 zaitor@opensuse.org
- Fix build for Leap 42.1 and 42.2, via tweaking conditional for
  compface/compface-devel BuildRequires.
* Tue Jun  2 2015 zaitor@opensuse.org
- Drop conditional pkgconfig(webkit2gtk-3.0) BuildRequires, as
  balsa now only supports webkit2gtk-4.0.
- Stop passing no longer recognized options:
  - -disable-scrollkeeper and --with-unique. Also remove a few
  obsolete conditionals.
* Mon Jun  1 2015 dimstar@opensuse.org
- Update to version 2.5.2:
  + Silence some autoconf and automake complaints.
  + Clean up store-address dialog.
  + Do not use header bar in GtkMessageDialog, it does nothing.
  + Use headerbars.
  + Deprecation cleanups.
  + Abandon buttons with both an icon and text, and use a symbolic
    icon where we keep the icon.
  + Enable the request of Delivery Status Notifications.
  + Disable SSLv3, with an option in the code to override, and
    enable TLSv1.1 and 1.2.
  + balsa.appdata.xml: new appdata file.
  + Fix S/MIME sending and Outlook2007 reception (bgo#720423).
- Drop balsa-support-webkit2gtk-4.0.patch: fixed upstream.
- Drop libtool BuildRequires and call to autoreconf, as we no
  longer carry any patches.
* Tue Dec 16 2014 zaitor@opensuse.org
- Make comface-devel BuildRequires only for releases newer than
  13.2, the split never made it into release.
* Thu Oct  9 2014 dimstar@opensuse.org
- Starting with openSUSE 13.2, compface was split into a -devel and
  library package. Conditionally BuildRequires compface-devel
  (openSUSE >= 1320).
* Tue Sep  9 2014 zaitor@opensuse.org
- Add balsa-support-webkit2gtk-4.0.patch: Support building with
  webkit2gtk3 (bgo#736493).
- Add conditional pkgconfig(webkit2gtk-4.0) BuildRequires for
  versions newer than 1310 as the above patch adds support for it.
- Add libtool BuildRequires and call to autoreconf, as above patch
  touches the build system.
* Wed May  1 2013 dimstar@opensuse.org
- Update to version 2.5.1:
  + Mew message header widget.
  + WebkitGtk2 widget integration.
  + Ported to GNetworkMonitor.
  + Yet another documentation port.
  + Initial config assistant improvements.
- Change --with-html-widget=webkit configure parameter to
  - -with-html-widget=webkit2, to switch to WebKit2.
- Replace gnome-doc-utils-devel BuildRequires with yelp-tools,
  following upstreams port to the new documentation infrastructure.
- Drop balsa-gtksourceview.patch: fixed upstream.
* Sat Apr  6 2013 dimstar@opensuse.org
- Update to version 2.5.0:
  + Making gtk3 build the official one.
- Rework BuildRequires for the large rewrite/port to GTK3:
  + Removed: pkgconfig(gconf-2.0), pkgconfig(gmime-2.4),
    pkgconfig(gnome-keyring-1), pkgconfig(gtk+-2.0),
    pkgconfig(gtksourceview-2.0), pkgconfig(gtkspell-2.0),
    pkgconfig(libbonobo-2.0), pkgconfig(libcanberra-gtk),
    pkgconfig(libgnome-2.0), pkgconfig(libgnomeui-2.0),
    pkgconfig(webkit-1.0)
  + Added: pkgconfig(gtk+-3.0), pkgconfig(gtksourceview-3.0),
    pkgconfig(gtkspell3-3.0), pkgconfig(libcanberra-gtk3),
    pkgconfig(libsecret-1), pkgconfig(webkitgtk-3.0).
- Add balsa-gtksourceview.patch: Fix build with gtksourceview 3.8.
* Tue Feb 26 2013 zaitor@opensuse.org
- Update to version 2.4.14:
  + Drop legacy gnome-icons-theme dependency.
  + Updated translations.
- Remove pkgconfig(gnome-icon-theme) BuildRequires, following
  upstream changes.
* Wed Oct 31 2012 dimstar@opensuse.org
- Update to version 2.4.13:
  + Fix long-line POP3 bug.
  + Bugs fixed: bgo#684124.
  + Updated translations.
* Wed Apr 25 2012 vuntz@opensuse.org
- Update to version 2.4.12:
  + New crypto implementation.
  + Build with GMime 2.6.0.
  + Various other code changes.
  + Updated translations.
- Drop balsa-gmime-2_6.patch: fixed upstream.
- Remove libtool BuildRequires and call to bootstrap.sh as they
  were only needed for above patch.
- Remove hack to rename sr@Latn translation to sr@latin: fixed
  upstream.
* Thu Jan 12 2012 dimstar@opensuse.org
- Build openSUSE > 12.1 against gmime 2.6: Conditionally change
  pkgconfig(gmime-2.4) BuildRequires to pkgconfig(gmime-2.6).
- Add balsa-gmime-2_6.patch: Allow building against gmime 2.6.
- Add libtool BuildRequires and call to bootstrap.sh as the patch
  above touches the build system.
* Fri Nov 25 2011 dimstar@opensuse.org
- Update to version 2.4.11:
  + more userfrendly view of filters' conditions
  + Bugs fixed: bgo#659390
  + Updated translations.
- Drop balsa-fix-linking.patch: fixed upstream.
- Remove call to gnome-autogen.sh and gnome-common BuildRequires.
* Wed Sep 21 2011 suse-tux@gmx.de
- Add balsa-fix-linking.patch: correctly link to the
  javascriptcoregtk library. This fixes the build.
- Add gnome-common BuildRequires and call to gnome-autogen.sh,
  needed for patch above.
* Tue Jun 14 2011 vuntz@opensuse.org
- Update to version 2.4.10:
  + Preserve identity order.
  + Trivial gtkhtml-3.15 support.
  + Improve interaction with unique.
  + Bugs fixed: bgo#636801, bgo#636805, bgo#647695.
- Drop balsa-fix-scrollkeeper.patch: fixed upstream.
- Drop balsa-mail-handler.patch: fixed upstream.
- Drop balsa-new-autotools.patch: fixed upstream.
- Drop balsa-message-searchbar-off.patch: fixed upstream.
- Remove call to autoreconf as we don't have any patch anymore.
* Fri Apr 15 2011 sbrabec@suse.cz
- Do not open message boxes with search bar (bgo#647695).
* Mon Mar 21 2011 sbrabec@suse.cz
- Support touchscreen version of balsa.
- Fixed URL.
- Added desktop file integration patch (bgo#645444).
- Fixed libnotify for 11.3 and older.
* Sat Feb 12 2011 vuntz@opensuse.org
- Call relevant macros in %%post/%%postun:
  + %%desktop_database_post/postun because the package ships at
    least one desktop file.
  + %%icon_theme_cache_post/postun because the package ships themed
    icons.
- Pass %%{?no_lang_C} to %%find_lang so that english documentation
  can be packaged with the program, and not in the lang subpackage.
- Change Requires of lang subpackage to Recommends, since the
  english documentation is not there anymore.
* Wed Dec  8 2010 vuntz@opensuse.org
- Cleanup previous changes to packages.
- Add explicit intltool BuildRequires.
- Add balsa-fix-scrollkeeper.patch to not have to manually remove
  the scrollkeeper files.
- Drop manpage_url_syntax.patch, as it's actually not needed.
* Mon Nov 22 2010 nmo.marques@gmail.com
- Update BuildRequires to use the pkgconfig() way:
  + Old ones: NetworkManager-devel, gconf2-devel, glib2-devel,
    gmime-2_4-devel, gnome-icon-theme-devel, gtk2-devel,
    gtksourceview-devel, gtkspell-devel, libcanberra-devel,
    libgnome-devel, libgnomeui-devel,
    libgnome-keyring-devel/gnome-keyring-devel, libnotify-devel,
    libunique-devel, libwebkit-devel, libxml2-devel, sqlite-devel.
  + New pkgconfig() ones: enchant, gconf-2.0, glib-2.0, gmime-2.4,
    gnome-icon-theme, gnome-keyring-1, gtk+-2.0, gtksourceview-2.0,
    gtkspell-2.0, libbonobo-2.0, libcanberra-gtk, libgnome-2.0,
    libgnomeui-2.0, libnm-glib, libnotify, libxml-2.0, sqlite3,
    unique-1.0, webkit-1.0.
- Add manpage_url_syntax.patch to fix man page syntax issue.
* Sat Nov 20 2010 nmo.marques@gmail.com
- Update to version 2.4.9:
  + Compile against new GTK, libnotify libs.
- Remove scrollkeeper files: we don't need them.
* Sun Aug 22 2010 dimstar@opensuse.org
- Update to version 2.4.8:
  + QUOTA and MYRIGHTS IMAP extension support.
  + bug fixes: bgo#625695, bgo#620221, bgo#623910, bgo#623740,
    bgo#618979, bgo#579479, bgo#613998
  + various memory leaks plugged.
* Sun Feb 14 2010 vuntz@opensuse.org
- Update to version 2.4.7:
  + infinite loop (deb#568298).
  + avoid crashes when manually verifing GPG signature.
  + new user pref to control quoting text.
- Replace --without-gtkhtml --with-webkit configure options with
  - -with-html-widget=webkit.
* Thu Jan 28 2010 vuntz@opensuse.org
- Update to version 2.4.6:
  + add forgotten part of filter comparison patch.
  + fix occasional IMAP failures on compressed connections.
- Pass --without-gtkhtml to configure to explicitly disable
  gtkhtml, and avoid a bug in the configure script.
* Mon Jan 25 2010 vuntz@opensuse.org
- Update to version 2.4.5:
  + Update menus only if necessary.
  + Fix build.
* Sun Jan 24 2010 vuntz@opensuse.org
- Update to version 2.4.3:
  + IMAP compression (COMPRESS=DEFLATE) when supported by server
  + Making opening attachment easier by saving them in a directory
  + Downloadable images when using Webkit html widget
  + Faster opening of the compose window.
  + Text searching enabled in the WebKit html viewer.
  + Options to hide toolbars and other parts of the UI (useful on
    netbooks etc).
  + For laptop/wifi users: not trying to reach POP3 servers while
    disconnected, and instead checking immediately on reconnection.
* Mon Jan  4 2010 vuntz@opensuse.org
- Change gnome-keyring-devel BuildRequires to
  libgnome-keyring-devel on 11.3 and later, following the module
  split upstream.
- Change the way we rename sr@Latn locale to sr@latin, so we don't
  have to call autoreconf.
- Do not manually change the CFLAGS: it's not needed anymore.
* Sun Dec  6 2009 dimstar@opensuse.org
- Update to version 2.4.2:
  + searching in HTML parts.
  + improved webkit support.
  + NetworkManager events intercepted to reconnect to IMAP servers.
  + compatibility with recent openssl.
  + compatibility with  gtk version >= 2.18
  + improved Mac OS X integration.
  + bug fixes.
  + Better translations.
- Add NetworkManager-devel BuildRequires.
- Removed docbook_4, perl-XML-Parser BuildRequires.
- Remove traces of balsa-gnome-icon-theme.patch, it's included
  upstream.
- Clean spec file using spec-cleaner.
* Fri Oct 23 2009 sbrabec@suse.cz
- Fallback to gnome-icon-theme, do not expect that system theme
  will do it (bgo#596309).
* Wed Aug 19 2009 beineri@opensuse.org
- Add an already translated GenericName to .desktop file.
* Mon Aug 10 2009 sbrabec@suse.cz
- Updated to version 2.4.1:
  * Continuing cleanup work: removing obsolete library calls.
  * partial workaround for the deadlock in xcb library code.
  * experimental use of libcanberra for sound.
  * many small bugfixes.
* Fri Jul 17 2009 coolo@novell.com
- build with large file support
* Tue Jun 30 2009 sbrabec@suse.cz
- Updated to version 2.4.0:
  * GMime-2.4, GLib-2.16, and Gtk-2.14 required.
  * Prefers libunique over BonoboActivation.
  * VCALENDAR and VEVENT handling.
  * deprecation cleanup.
  * message threading improvements and fixes.
  * Use GIO library when available.
  * Improve GMail IMAP compatibility.
  * porting to most recent GTK versions.
  * documentation ported to gnome-doc format.
  * partial translations of the manual to German and Spanish.
  * gnome-keyring is used if available (experimental).
  * initial experimental support for WebKit.
  * Bug fixes.
* Mon Feb 16 2009 sbrabec@suse.cz
- Added support for translation-update-upstream (FATE#301344).
* Wed Feb 11 2009 ro@suse.de
- use sr@latin instead of sr@Latn
* Mon Oct 13 2008 sbrabec@suse.cz
- Updated to version 2.3.25:
  * composing format=flowed messages with spaces pasted in works
    better.
  * allow to explicitly specify a GPG key id for an identity.
- Latest GTK+ deprecated GLib wrapper functions => removed
  GTK_DISABLE_DEPRECATED.
* Tue Jul 15 2008 sbrabec@suse.cz
- Updated to version 2.3.25:
  * GMail compatibility.
  * notification in GNOME panel are optional now.
  * wrapping of flowed text improved.
  * lots of various bug fixes.
  * Support for accessing files over gnome-vfs (smb, ssh mounts,
    etc.)
  * maildir tree scanning fixes.
  * Rudimentary support for sending text/html messages.
  * UIDPLUS IMAP extension support.
* Mon Apr  7 2008 sbrabec@suse.cz
- Updated to version 2.3.23:
  * Suppport for IMAP MULTIAPPEND extension for faster uploading
    of message batches to and from IMAP servers.
  * improved scanning of mailbox trees.
  * GtkSourceView2 support.
* Mon Jan 14 2008 sbrabec@suse.cz
- Updated to version 2.3.22:
  * new address edition widget in the compose window.
  * compose window displays languages available for spell checking.
  * more new icons.
  * migration from GnomeUI to GtkUIManager
  * Rubrica address book support.
  * Several bugs fixed.
* Tue Dec  4 2007 sbrabec@suse.cz
- Reduced BuildRequires.
* Thu Nov  1 2007 sbrabec@suse.cz
- Build feature complete with gtksourceview18.
* Thu Sep 20 2007 sbrabec@suse.cz
- Updated to version 2.3.20:
  * fix buffer overflow (#474366)
  * avoid sending messages twice under certain conditions
  * more build fixes
  * reflow improvements
  * Build problems against steaming-hot GNOME fixed
  * Make BINARY and ESEARCH IMAP extensions usage more robust
* Thu Sep 20 2007 sbrabec@suse.cz
- Fixed IMAP4 stack overflow (#326732, GNOME#474366).
* Mon Aug  6 2007 maw@suse.de
- Split out a -lang subpackage.
* Fri Aug  3 2007 maw@suse.de
- Build without gtksourceview support (#297259).
* Fri Jul 27 2007 maw@suse.de
- Add dont-disable-deprecated.patch.
* Mon Jul  9 2007 sbrabec@suse.cz
- Updated to version 2.3.17:
  * APOP server signature verification and few other capabilitites
  * supports GtkPrint, LDAP referrals, IMAP BINARY
  * few more performance fixes and new features
  * number of bug fixes
* Thu May 10 2007 pgajdos@suse.cz
- fixed warning of new gcc: comparsion with string literal
- string-literal-send2.patch
* Wed May  9 2007 pgajdos@suse.cz
- removed gnome-icon-theme from BuildRequires and Requires
  [#247450]
* Tue Feb 20 2007 mvaner@suse.cz
- Comparison with string literal (bug #229781)
  - string-literal-send.patch
* Mon Dec 18 2006 sbrabec@suse.cz
- Prefix changed to /usr.
- Spec file cleanup.
* Fri Oct 20 2006 sbrabec@suse.cz
- Updated to version 2.3.13:
  * nicer icons.
  * do not reference freed memory in mbox driver.
  * assure messages are properly signed after identity change.
  * Ctrl-N goes over unread messages in all mailboxes.
  * Redone Preference Manager.
  * support better slow LDAP servers.
  * use better real estate when displaying message counts.
  * local mailbox opening acceleration.
  * composed message saving and postponing UI improvements.
  * fix mailbox locking regressions.
  * GtkSpell improvements.
  * bug fixes
* Sun Aug  6 2006 aj@suse.de
- Fix build.
* Wed Jun 14 2006 schwab@suse.de
- Fix syntax error in configure script.
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Tue Jan 17 2006 sbrabec@suse.cz
- Updated to version 2.3.8.
- Enabled GtkSpell and Compface.
* Sat Jan 14 2006 kukuk@suse.de
- Add gpgme-devel to nfb
* Tue Nov  8 2005 sbrabec@suse.cz
- Use sqlite3.
* Sun Sep 25 2005 ro@suse.de
- added LDAP_DEPRECATED to CFLAGS
* Mon Aug 29 2005 ro@suse.de
- added "--ignore-theme-index" to gtk-update-icon-cache call
* Fri Jul 15 2005 sbrabec@suse.cz
- Updated to version 2.3.4.
* Tue Mar  1 2005 sbrabec@suse.cz
- Fixed for latest gmime.
* Tue Feb  1 2005 sbrabec@suse.cz
- Turned on sqlite support.
* Tue Feb  1 2005 ro@suse.de
- do not define GNOME_DISABLE_DEPRECATED
- do not define GTK_DISABLE_DEPRECATED
* Wed Jan 19 2005 ro@suse.de
- do not define -DGNOME_VFS_DISABLE_DEPRECATED
* Thu Jan  6 2005 sbrabec@suse.cz
- Updated to version 2.2.6.
* Tue Nov 23 2004 ro@suse.de
- added db-devel to neededforbuild (for <= 9.0)
- fix build with heimdal for (<= 9.2)
* Sun Nov 21 2004 ro@suse.de
- run autoreconf and fix build with mit-kerberos
* Fri Nov 19 2004 ro@suse.de
- postfix is in neededforbuild, so skip sendmail
* Thu Nov 18 2004 ro@suse.de
- use kerberos-devel-packages (might need more work)
* Tue Oct 26 2004 ro@suse.de
- locale rename: no -> nb
* Tue Oct 12 2004 sbrabec@suse.cz
- Use gnutls instead of openssl (#44438).
* Fri Sep  3 2004 sbrabec@suse.cz
- Updated to version 2.2.4.
* Sun Jul 25 2004 ro@suse.de
- added libgpg-error to neededforbuild
* Mon May 24 2004 ro@suse.de
- don't DEPRECATE gtk and gnome
- re-generate Balsa-Stubs.c
* Thu Mar 25 2004 mmj@suse.de
- Add postfix to # neededforbuild
* Thu Feb  5 2004 sbrabec@suse.cz
- Updated to version 2.0.16.
* Sat Jan 10 2004 adrian@suse.de
- build as user
* Tue Aug 12 2003 adrian@suse.de
- add Categories
* Thu Aug  7 2003 sbrabec@suse.cz
- Updated to version 2.0.13.
- Turned on all optional features.
* Wed Jul 30 2003 hhetter@suse.de
- build with libesmtp support
* Mon Jul 14 2003 sbrabec@suse.cz
- GNOME prefix change to /opt/gnome.
* Thu Jun  5 2003 ltinkl@suse.cz
- updated to version 2.0.11
  * considerably improved GPG support
  * text wrapping improvements
  * charset encoding validation and conversion improvements
  * minor LDAP fixes (large directories, non-US-ASCII characters)
* Mon Feb 17 2003 sbrabec@suse.cz
- Updated to version 2.0.8.
* Tue Feb 11 2003 sbrabec@suse.cz
- Update to version 2.0.7 (GNOME 2).
* Mon Nov 11 2002 ro@suse.de
- changed neededforbuild <jade_dsl> to <openjade>
* Fri Nov  1 2002 pmladek@suse.cz
- fixed to use new aspell (pspell was merged into new aspell)
- removed CPP, CXX hacks from configure.ac
* Wed Oct  9 2002 tcrhak@suse.cz
- added alsa and alsa-devel to neededforbuild
- replaced LIBOBJS by AC_LIBOBJ in libmutt/configure.in
* Wed Oct  2 2002 nadvornik@suse.cz
- removed libPropList from neededforbuild
* Tue Aug 13 2002 hhetter@suse.de
- fix neededforbuild
* Mon Aug  5 2002 prehak@suse.cz
- update to version 1.2.4
- added openssl and openssl-devel to neededforbuild
* Thu Jun 20 2002 ro@suse.de
- use "-a -f" for automake
* Wed Apr  3 2002 tcrhak@suse.cz
- build with new automake/autoconf
* Fri Mar 15 2002 tcrhak@suse.cz
- added dirs to filelist:
  %%{prefix}/share/gnome/help/balsa
  %%{prefix}/share/sounds/balsa
* Thu Jan 31 2002 ro@suse.de
- changed neededforbuild <libpng> to <libpng-devel-packages>
* Fri Nov 30 2001 ro@suse.de
- changed neededforbuild <docbktls> to <docbook-toys>
* Tue Nov 20 2001 ro@suse.de
- added freetype2 to neededforbuild
* Mon Nov 19 2001 ro@suse.de
- up to 1.2.3
- build with automake 1.5
* Fri Aug 17 2001 adostal@suse.cz
- update to version 1.1.7
- create pspell patch and ia64 patch
- fixed specfile (neededforbuild, build, install)
* Fri Aug 10 2001 ro@suse.de
- fixed specfile to build
* Tue Jun 26 2001 ro@suse.de
- fix to build with new autoconf and c++-ed pspell
* Wed May 23 2001 pblaha@suse.cz
- fix cast warning on ia64
* Thu Mar 29 2001 pblaha@suse.cz
- fix compilation with pspell
* Sun Feb 25 2001 egger@suse.de
- Remove unnecessary dependencies from #neededforbuild,
  especially imlib-config.
* Tue Jan 30 2001 ro@suse.de
- changed neededforbuild <imlibcfe> to <imlib-config>
* Mon Jan  1 2001 egger@suse.de
- Cleaned up specfile.
- Recompressed with bzip2.
* Wed Nov 15 2000 ro@suse.de
- fixed neededforbuild for libPropList
* Wed Nov 15 2000 hhetter@suse.de
- update to version 1.0.0
* Mon Nov  6 2000 ro@suse.de
- fixed typos
* Wed Nov  1 2000 egger@suse.de
- Updated specfile to new long packagenames.
- Reworked specfile.
- Probably needs some more work; I'm taking care of that.
* Tue Sep 19 2000 egger@suse.de
- Tweaked #neededforbuild again.
* Tue Sep 19 2000 egger@suse.de
- Updated to version 0.9.5
- Tweaked specfile.
- Buildproofed on i386.
* Fri Sep 15 2000 ro@suse.de
- fixed to compile
* Tue Sep  5 2000 egger@suse.de
- Updated to version 0.9.4.
* Tue Aug 29 2000 egger@suse.de
- Updated to version 0.9.3.
* Wed Jul 12 2000 smid@suse.cz
- man page location changed (bugzilla #3099)
* Thu Jul  6 2000 pthomas@suse.de
- use absolute path for man page symlink
* Fri Jun  9 2000 smid@suse.cz
- upgrade to 0.8.0
* Thu Apr 13 2000 smid@suse.cz
- upgrade to 0.6.0
* Mon Sep 13 1999 bs@suse.de
- ran old prepare_spec on spec file to switch to new prepare_spec.
* Wed Jul 14 1999 ke@suse.de
- use libungif instead of libgif.
- use proplst and proplstd instead of wmaker.
* Tue Jul 13 1999 bs@suse.de
- use gtk and glib instead of gtkn and glibn
* Fri Feb 19 1999 ke@suse.de
- use sysconfdir=/etc/opt/gnome.
* Fri Feb 19 1999 ro@suse.de
- added esound and audiofil to neededforbuild
* Fri Feb 12 1999 ke@suse.de
- #neededforbuild indent.
- rebuilt orbit's files.
* Thu Jan 28 1999 ke@suse.de
- New package: initial version 0.4.9 (recommeded and prepared by ray).
